==> layer_sdk-0.9.347249-py3-none-any.whl: layer/projects/entity.py <==
from dataclasses import dataclass
from enum import Enum, unique
from typing import Any, Optional, Type, Union

from yarl import URL

from layer import DerivedDataset, Featureset, Model


@unique
class EntityStatus(str, Enum):
    PENDING = "pending"
    SAVING = "saving"
    BUILDING = "building"
    TRAINING = "training"
    DONE = "done"
    ERROR = "error"
    ASSERTING = "asserting"

    @property
    def is_running(self) -> bool:
        return self in (
            EntityStatus.SAVING,
            EntityStatus.BUILDING,
            EntityStatus.TRAINING,
            EntityStatus.ASSERTING,
        )

    @property
    def is_finished(self) -> bool:
        return self in (EntityStatus.DONE, EntityStatus.ERROR)


@unique
class EntityType(str, Enum):
    RAW_DATASET = "raw_dataset"
    DERIVED_DATASET = "derived_dataset"
    FEATURESET = "featureset"
    MODEL = "model"

    def get_url(
        self, base_url: URL, project_name: str, account_name: str, **kwargs: Any
    ) -> URL:
        if self == EntityType.FEATURESET:
            return (
                base_url
                / account_name
                / project_name
                / "featuresets"
                / str(kwargs["id"])
            )
        if self == EntityType.MODEL:
            url = (
                base_url / account_name / project_name / "models" / str(kwargs["name"])
            )
            return url
        if self == EntityType.DERIVED_DATASET:
            return (
                base_url
                / account_name
                / project_name
                / "datasets"
                / str(kwargs["name"])
            )
        raise RuntimeError(f"Unsupported entity type: {self}")

    def get_factory(
        self,
    ) -> Union[Type[DerivedDataset], Type[Featureset], Type[Model]]:
        if self == EntityType.DERIVED_DATASET:
            return DerivedDataset
        elif self == EntityType.FEATURESET:
            return Featureset
        elif self == EntityType.MODEL:
            return Model
        else:
            raise RuntimeError(f"Unsupported entity type: {self}")


@dataclass
class Entity:
    type: EntityType
    name: str
    status: EntityStatus = EntityStatus.PENDING
    url: Optional[URL] = None
    error_reason: str = ""

    @property
    def is_running(self) -> bool:
        return self.status.is_running

    @property
    def is_finished(self) -> bool:
        return self.status.is_finished

==> layer_sdk-0.9.350311-py3-none-any.whl: layer/projects/entity.py <==
from dataclasses import dataclass
from enum import Enum, unique
from typing import Any, Optional, Type, Union

from yarl import URL

from layer import DerivedDataset, Model


@unique
class EntityStatus(str, Enum):
    PENDING = "pending"
    SAVING = "saving"
    BUILDING = "building"
    TRAINING = "training"
    DONE = "done"
    ERROR = "error"
    ASSERTING = "asserting"

    @property
    def is_running(self) -> bool:
        return self in (
            EntityStatus.SAVING,
            EntityStatus.BUILDING,
            EntityStatus.TRAINING,
            EntityStatus.ASSERTING,
        )

    @property
    def is_finished(self) -> bool:
        return self in (EntityStatus.DONE, EntityStatus.ERROR)


@unique
class EntityType(str, Enum):
    RAW_DATASET = "raw_dataset"
    DERIVED_DATASET = "derived_dataset"
    MODEL = "model"

    def get_url(
        self, base_url: URL, project_name: str, account_name: str, **kwargs: Any
    ) -> URL:
        if self == EntityType.MODEL:
            url = (
                base_url / account_name / project_name / "models" / str(kwargs["name"])
            )
            return url
        if self == EntityType.DERIVED_DATASET:
            return (
                base_url
                / account_name
                / project_name
                / "datasets"
                / str(kwargs["name"])
            )
        raise RuntimeError(f"Unsupported entity type: {self}")

    def get_factory(
        self,
    ) -> Union[Type[DerivedDataset], Type[Model]]:
        if self == EntityType.DERIVED_DATASET:
            return DerivedDataset
        elif self == EntityType.MODEL:
            return Model
        else:
            raise RuntimeError(f"Unsupported entity type: {self}")


@dataclass
class Entity:
    type: EntityType
    name: str
    status: EntityStatus = EntityStatus.PENDING
    url: Optional[URL] = None
    error_reason: str = ""

    @property
    def is_running(self) -> bool:
        return self.status.is_running

    @property
    def is_finished(self) -> bool:
        return self.status.is_finished
